@@ -1,7 +1,7 @@
 /*
 mailtextbody - a program that returns the body of an email message
 
-Copyright (C) 2005-2012 Toastfreeware <toast@toastfreeware.priv.at> - 
+Copyright (C) 2005-2024 Toastfreeware <toast@toastfreeware.priv.at> - 
 Philipp Spitzer and Gregor Herrmann
 
 This program is free software; you can redistribute it and/or modify
@@ -29,16 +29,33 @@ using namespace std;
 using namespace mimetic;
 
 
-const char *argp_program_version = "mailtextbody 0.1.4";
+const char *argp_program_version = "mailtextbody 0.1.5";
 const char *argp_program_bug_address = "<toast@toastfreeware.priv.at>";
 static char doc[] = "mailtextbody - a program that returns the body of an email message";
 static char args_doc[] = "mailtextbody < rawmail > textplain";
-static struct argp_option argp_options[] = {{0}};
+static const struct argp_option argp_options[] = {
+	{"mimetype", 'm', "value", 0, "MIME type to look for, default \"text/plain\".", 0},
+	{0}
+};
+
+
+struct arguments
+{
+	const char* mime_type = "text/plain";
+};
 
 
 // parse function for the program options
-static error_t parse_opt(int, char*, argp_state*) {
-	return (error_t)ARGP_ERR_UNKNOWN;
+static error_t parse_opt(int key, char* arg, argp_state* state) {
+	struct arguments* arguments = (struct arguments*) state->input;
+	switch (key) {
+	case 'm':
+		arguments->mime_type = arg;
+		break;
+	default:
+		return ARGP_ERR_UNKNOWN;
+	}
+	return 0;
 }
 
 
@@ -78,11 +95,12 @@ bool findMimePart(MimeEntity* pMe, const string& mimeType) {
 
 
 int main(int argc, char *argv[]) {
-	// parse command line options	
-	argp_parse (&argp, argc, argv, 0, 0, 0);
+	// parse command line options
+	struct arguments arguments;
+	argp_parse(&argp, argc, argv, 0, 0, &arguments);
 
 	MimeEntity me(cin); // parse and load message
-	if (!findMimePart(&me, "text/plain")) {
+	if (!findMimePart(&me, arguments.mime_type)) {
 		if (me.header().mimeVersion().str() == "0.0") cout << me.body();
 	}
 	return 0;
